pype32.pype32.OptionalHeader64

Package pype32 :: Module pype32 :: Class OptionalHeader64 |
[hide private]
[frames] | no frames]

# Class OptionalHeader64

source code

                     object --+
                              |
    baseclasses.BaseStructClass --+
                                  |
                                 OptionalHeader64

OptionalHeader64 object.

Instance Methods | [hide private]
__init__(self, shouldPack=True) Class representation of the `IMAGE_OPTIONAL_HEADER64` structure. | source code
getType(self) Returns consts.IMAGE_OPTIONAL_HEADER64. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`
Inherited from baseclasses.BaseStructClass
__len__(self) | source code
__str__(self) str(x) | source code
dict |
getFields(self) Returns all the class attributues. | source code
sizeof(self) | source code

Static Methods | [hide private]
OptionalHeader64 |
parse(readDataInstance) Returns a new OptionalHeader64 object. | source code

Instance Variables | [hide private]
| magic WORD magic.
| majorLinkerVersion BYTE majorLinkerVersion.
| minorLinkerVersion BYTE minorLinkerVersion.
| sizeOfCode DWORD sizeOfCode.
| sizeOfInitializedData DWORD sizeOfInitializedData.
| sizeOfUninitializedData DWORD sizeOfUninitializedData.
| addressOfEntryPoint DWORD addressOfEntryPoint.
| baseOfCode DWORD baseOfCode.
| imageBase QWORD imageBase.
| sectionAlignment DWORD sectionAlignment.
| fileAlignment DWORD fileAligment.
| majorOperatingSystemVersion WORD majorOperatingSystemVersion.
| minorOperatingSystemVersion WORD minorOperatingSystemVersion.
| majorImageVersion WORD majorImageVersion.
| minorImageVersion WORD minorImageVersion.
| majorSubsystemVersion WORD majorSubsystemVersion.
| minorSubsystemVersion WORD minorSubsystemVersion.
| win32VersionValue DWORD win32VersionValue.
| sizeOfImage DWORD sizeOfImage.
| sizeOfHeaders DWORD sizeOfHeaders.
| checksum DWORD checksum.
| subsystem WORD subsystem.
| dllCharacteristics WORD dllCharacteristics.
| sizeOfStackReserve QWORD sizeOfStackReserve.
| sizeOfStackCommit QWORD sizeOfStackCommit.
| sizeOfHeapReserve QWORD sizeOfHeapReserve.
| sizeOfHeapCommit QWORD sizeOfHeapCommit.
| loaderFlags DWORD loaderFlags.
| numberOfRvaAndSizes DWORD numberOfRvaAndSizes.
| dataDirectory DataDirectory dataDirectory.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, shouldPack=True) (Constructor) | source code
Class representation of the `IMAGE_OPTIONAL_HEADER64` structure. Parameters: `shouldPack` (bool) - (Optional) If set to `True`, the object will be packed. If set to `False`, the object won't be packed. Overrides: object.__init__ See Also: Remarks in http://msdn.microsoft.com/en-us/library/windows/desktop/ms680339%28v=vs.85%29.aspx

### parse(readDataInstance) Static Method | source code
Returns a new OptionalHeader64 object. Parameters: `readDataInstance` (ReadData) - A ReadData object with data to be parsed as a OptionalHeader64 object. Returns: OptionalHeader64 A new OptionalHeader64 object.

### getType(self) | source code
Returns consts.IMAGE_OPTIONAL_HEADER64. Raises: `NotImplementedError` - The method wasn't implemented in the inherited class. Overrides: baseclasses.BaseStructClass.getType